==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/DependabotIgnore.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) You can use the `ignore` option to customize which dependencies are updated.
 * <p>
 * The ignore option supports the following options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.757Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.DependabotIgnore")
@software.amazon.jsii.Jsii.Proxy(DependabotIgnore.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface DependabotIgnore extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Use to ignore updates for dependencies with matching names, optionally using `*` to match zero or more characters.
     * <p>
     * For Java dependencies, the format of the dependency-name attribute is:
     * <code>groupId:artifactId</code>, for example: <code>org.kohsuke:github-api</code>.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getDependencyName();

    /**
     * (experimental) Use to ignore specific versions or ranges of versions.
     * <p>
     * If you want to
     * define a range, use the standard pattern for the package manager (for
     * example: <code>^1.0.0</code> for npm, or <code>~&gt; 2.0</code> for Bundler).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getVersions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link DependabotIgnore}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link DependabotIgnore}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<DependabotIgnore> {
        java.lang.String dependencyName;
        java.util.List<java.lang.String> versions;

        /**
         * Sets the value of {@link DependabotIgnore#getDependencyName}
         * @param dependencyName Use to ignore updates for dependencies with matching names, optionally using `*` to match zero or more characters. This parameter is required.
         *                       For Java dependencies, the format of the dependency-name attribute is:
         *                       <code>groupId:artifactId</code>, for example: <code>org.kohsuke:github-api</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dependencyName(java.lang.String dependencyName) {
            this.dependencyName = dependencyName;
            return this;
        }

        /**
         * Sets the value of {@link DependabotIgnore#getVersions}
         * @param versions Use to ignore specific versions or ranges of versions.
         *                 If you want to
         *                 define a range, use the standard pattern for the package manager (for
         *                 example: <code>^1.0.0</code> for npm, or <code>~&gt; 2.0</code> for Bundler).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder versions(java.util.List<java.lang.String> versions) {
            this.versions = versions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link DependabotIgnore}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public DependabotIgnore build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link DependabotIgnore}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements DependabotIgnore {
        private final java.lang.String dependencyName;
        private final java.util.List<java.lang.String> versions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.dependencyName = software.amazon.jsii.Kernel.get(this, "dependencyName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.versions = software.amazon.jsii.Kernel.get(this, "versions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.dependencyName = java.util.Objects.requireNonNull(builder.dependencyName, "dependencyName is required");
            this.versions = builder.versions;
        }

        @Override
        public final java.lang.String getDependencyName() {
            return this.dependencyName;
        }

        @Override
        public final java.util.List<java.lang.String> getVersions() {
            return this.versions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("dependencyName", om.valueToTree(this.getDependencyName()));
            if (this.getVersions() != null) {
                data.set("versions", om.valueToTree(this.getVersions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.DependabotIgnore"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            DependabotIgnore.Jsii$Proxy that = (DependabotIgnore.Jsii$Proxy) o;

            if (!dependencyName.equals(that.dependencyName)) return false;
            return this.versions != null ? this.versions.equals(that.versions) : that.versions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.dependencyName.hashCode();
            result = 31 * result + (this.versions != null ? this.versions.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/DependabotIgnore.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) You can use the <code>ignore</code> option to customize which dependencies are updated.
 * <p>
 * The ignore option supports the following options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.417Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.DependabotIgnore")
@software.amazon.jsii.Jsii.Proxy(DependabotIgnore.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface DependabotIgnore extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Use to ignore updates for dependencies with matching names, optionally using <code>*</code> to match zero or more characters.
     * <p>
     * For Java dependencies, the format of the dependency-name attribute is:
     * <code>groupId:artifactId</code>, for example: <code>org.kohsuke:github-api</code>.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getDependencyName();

    /**
     * (experimental) Use to ignore specific versions or ranges of versions.
     * <p>
     * If you want to
     * define a range, use the standard pattern for the package manager (for
     * example: <code>^1.0.0</code> for npm, or <code>~&gt; 2.0</code> for Bundler).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getVersions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link DependabotIgnore}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link DependabotIgnore}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<DependabotIgnore> {
        java.lang.String dependencyName;
        java.util.List<java.lang.String> versions;

        /**
         * Sets the value of {@link DependabotIgnore#getDependencyName}
         * @param dependencyName Use to ignore updates for dependencies with matching names, optionally using <code>*</code> to match zero or more characters. This parameter is required.
         *                       For Java dependencies, the format of the dependency-name attribute is:
         *                       <code>groupId:artifactId</code>, for example: <code>org.kohsuke:github-api</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dependencyName(java.lang.String dependencyName) {
            this.dependencyName = dependencyName;
            return this;
        }

        /**
         * Sets the value of {@link DependabotIgnore#getVersions}
         * @param versions Use to ignore specific versions or ranges of versions.
         *                 If you want to
         *                 define a range, use the standard pattern for the package manager (for
         *                 example: <code>^1.0.0</code> for npm, or <code>~&gt; 2.0</code> for Bundler).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder versions(java.util.List<java.lang.String> versions) {
            this.versions = versions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link DependabotIgnore}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public DependabotIgnore build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link DependabotIgnore}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements DependabotIgnore {
        private final java.lang.String dependencyName;
        private final java.util.List<java.lang.String> versions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.dependencyName = software.amazon.jsii.Kernel.get(this, "dependencyName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.versions = software.amazon.jsii.Kernel.get(this, "versions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.dependencyName = java.util.Objects.requireNonNull(builder.dependencyName, "dependencyName is required");
            this.versions = builder.versions;
        }

        @Override
        public final java.lang.String getDependencyName() {
            return this.dependencyName;
        }

        @Override
        public final java.util.List<java.lang.String> getVersions() {
            return this.versions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("dependencyName", om.valueToTree(this.getDependencyName()));
            if (this.getVersions() != null) {
                data.set("versions", om.valueToTree(this.getVersions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.DependabotIgnore"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            DependabotIgnore.Jsii$Proxy that = (DependabotIgnore.Jsii$Proxy) o;

            if (!dependencyName.equals(that.dependencyName)) return false;
            return this.versions != null ? this.versions.equals(that.versions) : that.versions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.dependencyName.hashCode();
            result = 31 * result + (this.versions != null ? this.versions.hashCode() : 0);
            return result;
        }
    }
}
